/*
 	File:		HIWindowTypes.h
 
 	Version:	Technology:	Copland
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __HIWINDOWTYPES__
#define __HIWINDOWTYPES__

#ifndef __TYPES__
#include <Types.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=power
/* the following contents can only be used by compilers that support PowerPC struct alignment */

#if FOR_SYSTEM8_COOPERATIVE
#ifdef __cplusplus
	class HIWindow;
#else
	#include <som.h>
	#ifndef HIWindow
		#define HIWindow SOMObject
	#endif
#endif
typedef struct OpaqueHILayerRef* HILayerRef;
typedef struct OpaqueHIWindowGroupRef* HIWindowGroupRef;

enum {
	kHIStateChangeWindowZOrderChanging = 'z1  ',				/* new state-changed codes for windows*/
	kHIStateChangeWindowZOrderChanged = 'z2  ',
	kHIStateChangeWindowCollapsed = 'clps',
	kHIStateChangeWindowExpanded = 'expn',
	kHIBehindWindowTag			= 'bwnd'						/* during z-order changing callback, new behindWindow is found at [tag: kHIBehindWindowTag, index: 1]*/
};

/* Window class encompasses window frame style, z-order, and default system behavior*/
typedef UInt32 HIWindowClass;

enum {
	kHIWindowModalClass			= 0,
	kHIWindowFloatingClass		= 1,
	kHIWindowNormalClass		= 2
};

/* Different types of windows in each window class*/
typedef UInt32 HIWindowVariant;

enum {
	kHIWindowDocumentVariant	= 0,							/* following are for use with kHIWindowNormalClass*/
	kHIWindowModalDialogVariant	= 1,
	kHIWindowPlainDialogVariant	= 2,
	kHIWindowShadowDialogVariant = 3,
	kHIWindowMovableModalDialogVariant = 5,
	kHIWindowAlertVariant		= 7,
	kHIWindowMovableAlertVariant = 9,
	kHIWindowBorderlessNormalVariant = 10,
	kHIWindowStandardFloaterVariant = 0,						/* for use with kHIWindowFloatingClass*/
	kHIWindowBorderlessFloaterVariant = 1,
	kHIWindowSideFloaterVariant	= 8
};

/* Attributes for any window*/
typedef OptionBits HIWindowAttributes;

enum {
	kHIWindowHasGrow			= 0x00000001,
	kHIWindowRightToLeftOrientation = 0x00000002,
	kHIWindowPreventsProcessSwitching = 0x00000004,
	kHIWindowHasHorizontalZoom	= 0x00000008,
	kHIWindowHasVerticalZoom	= 0x00000010,
	kHIWindowHasFullZoom		= (kHIWindowHasHorizontalZoom | kHIWindowHasVerticalZoom),
	kHIWindowHasClose			= 0x00000020,
	kHIWindowDoesTitleIconDrag	= 0x00000040,
	kHIWindowHasCollapse		= 0x00000080,
	kHIWindowDoNotEraseContent	= 0x00000100,
	kHIWindowNoUpdateEvents		= 0x00000200,
	kHIWindowNoActivateEvents	= 0x00000400,
	kHIWindowWantsBackgroundContentClicks = 0x00000800,
	kHIWindowAutomaticAlignment	= 0x00001000,
	kHIWindowQuitOnClose		= 0x00002000,
	kHIWindowHasCloseBox		= kHIWindowHasClose,			/* names without "Box" are preferred*/
	kHIWindowHasCollapseBox		= kHIWindowHasCollapse,
	kHIWindowReservedAttributes	= 0xFFFFC000,
	kHIWindowStandardDocumentAttributes = (kHIWindowHasGrow | kHIWindowHasFullZoom | kHIWindowHasClose | kHIWindowDoesTitleIconDrag | kHIWindowHasCollapse),
	kHIWindowStandardUtilityAttributes = (kHIWindowHasClose | kHIWindowHasCollapse)
};

/* Parameters for the behindThisWindow argument of InitWindow/InitWindowInLayer*/

enum {
	kHIFirstWindowOfClass		= -1,
	kHILastWindowOfClass		= 0
};

/* Parameters for the rootPanel argument of InitWindow/InitWindowInLayer*/

enum {
	kHIWindowDefaultRootPanel	= -1,
	kHIWindowNoRootPanel		= 0
};

/* Vertical, horizontal, and location constraints are used with PositionOnScreen and AutoPosition*/
typedef UInt32 HIWindowVerticalConstraint;

enum {
	kHIWindowNoVerticalConstraint = 0,
	kHIWindowDocumentVerticalCenter = 1,
	kHIWindowAlertVerticalCenter = 2,
	kHIWindowVerticalStagger	= 3
};

typedef UInt32 HIWindowHorizontalConstraint;

enum {
	kHIWindowNoHorizontalConstraint = 0,
	kHIWindowHorizontalCenter	= 1
};

typedef UInt32 HIWindowLocationConstraint;

enum {
	kHIWindowMainScreen			= 0,
	kHIWindowParentWindowScreen	= 1,
	kHIWindowParentWindow		= 2
};

/*Parts of a window frame*/
typedef SInt32 HIWindowPartCode;

enum {
	kHIWindowFramePart			= -1,							/* for use only with IsPositionedOnScreen*/
	kHIWindowNoPart				= 0,
	kHIWindowContentPart		= 1,
	kHIWindowDragPart			= 2,
	kHIWindowGrowPart			= 3,
	kHIWindowClosePart			= 4,
	kHIWindowZoomInPart			= 5,
	kHIWindowZoomOutPart		= 6,
	kHIWindowCustomBoxPart		= 7,
	kHIWindowTitleIconPart		= 8,
	kHIWindowCollapsePart		= 9
};

/* Similar to window part codes, but with slightly finer granularity*/
typedef UInt32 HIWindowRgnCode;

enum {
	kHIWindowTitleBarRgn		= 0,
	kHIWindowTitleTextRgn		= 1,
	kHIWindowCloseBoxRgn		= 2,
	kHIWindowZoomBoxRgn			= 3,
	kHIWindowIconBoxRgn			= 4,
	kHIWindowDragRgn			= 5,
	kHIWindowGrowRgn			= 6,
	kHIWindowCollapseBoxRgn		= 7,
	kHIWindowStructureRgn		= 32,
	kHIWindowContentRgn			= 33
};

/*Returned by GetGrowDirection*/
typedef OptionBits HIWindowGrowDirection;

enum {
	kHIWindowGrowUp				= 0x01,
	kHIWindowGrowLeft			= 0x02,
	kHIWindowGrowDown			= 0x04,
	kHIWindowGrowRight			= 0x08
};

#endif

#pragma options align=reset
#endif /* PRAGMA_ALIGN_SUPPORTED */

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __HIWINDOWTYPES__ */

