/*
 	File:		IOMemoryLists.h
 
 	Contains:	Memory List API
 
 	Version:	Technology:	Copland
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __IOMEMORYLISTS__
#define __IOMEMORYLISTS__

#ifndef __TYPES__
#include <Types.h>
#endif
#ifndef __KERNEL__
#include <Kernel.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=power
/* the following contents can only be used by compilers that support PowerPC struct alignment */

typedef struct OpaqueMemListRef* MemListRef;
typedef struct OpaqueMemListDescriptorRef* MemListDescriptorRef;

enum {
	kMemListByteAbsolute		= 0x00000001,
	kMemListByteRelative		= 0x00000002,
	kMemListPageAbsolute		= 0x00000004,
	kMemListPageRelative		= 0x00000008,
	kMemListPhysicalExtentAbsolute = 0x00000010,
	kMemListPhysicalExtentRelative = 0x00000020,
	kMemListStaticLogicalExtentAbsolute = 0x00000040,
	kMemListStaticLogicalExtentRelative = 0x00000080,
	kMemListInputExtentAbsolute	= 0x00000100,
	kMemListInputExtentRelative	= 0x00000200
};

typedef UInt32 MemListWhence;
/*
****************************************************************************

	Basic error types
	
 ***************************************************************************
*/

enum {
	E_MemListSuccess			= 0x00000000,
	E_MemListCantAllocate		= -2600,
	E_MemListEndOfList			= -2601,
	E_MemListNotPrivileged		= -2602,
	E_MemListBadMemList			= -2603,
	E_MemListOutOfRange			= -2604
};

struct MemListInfo {
	ItemCount 						numDescriptors;
	ItemCount 						numRanges;
	ItemCount 						numPages;
	Boolean 						isFinalized;
	Boolean 						isPrepared;
};
typedef struct MemListInfo MemListInfo;

struct MemListDescriptorInfo {
	ByteCount 						len;
	IOPreparationOptions 			preparationOptions;
	MemListDescriptorRef 			parentDescriptor;
	MemListRef 						parentMemList;
	Boolean 						isPrepared;
};
typedef struct MemListDescriptorInfo MemListDescriptorInfo;

/*
******************************************************************************
 *******************************************************************************

	Memory List Creation and Initialization
	
 *******************************************************************************
 *****************************************************************************
*/
extern OSStatus MemListCreate(ItemCount anticipatedRanges, MemListRef *newMemList);

extern OSStatus MemListCreatePriv(ItemCount anticipatedRanges, AddressSpaceID addressSpace, MemListRef *newMemList);

extern OSStatus MemListCreatePhysPriv(ItemCount anticipatedRanges, MemListRef *newMemList);

extern OSStatus MemListAddRange(MemListRef memList, LogicalAddress start, ByteCount length);

extern OSStatus MemListAddPhysRange(MemListRef memList, PhysicalAddress start, ByteCount length);

extern OSStatus MemListFinalize(MemListRef finalizeList, MemListDescriptorRef *newDescriptor);

/*
******************************************************************************
 *******************************************************************************

	Memory List Descriptor Manipulation
	
 *******************************************************************************
 *****************************************************************************
*/
extern OSStatus MemListAddSimpleDescriptor(MemListDescriptorRef srcDescriptor, ByteCount len, MemListDescriptorRef *newDescriptor);

extern OSStatus MemListCloneDescriptor(MemListDescriptorRef srcDescriptor, MemListDescriptorRef *newDescriptor);

extern OSStatus MemListDeleteDescriptor(MemListDescriptorRef deleteDescriptor);

extern OSStatus MemListPrepareDescriptorForIO(MemListDescriptorRef srcDescriptor, ByteCount requestedLen, ByteCount granularity, OptionBits options, MemListDescriptorRef *newDescriptor, ByteCount *mappedLen);

extern OSStatus MemListCheckPointDescriptor(MemListDescriptorRef checkpointDescriptor, IOCheckpointOptions theOptions);

extern OSStatus MemListGetInfo(MemListRef infoDescriptor, MemListInfo *info);

extern OSStatus MemListGetDescriptorInfo(MemListDescriptorRef infoDescriptor, MemListDescriptorInfo *info);

extern OSStatus MemListDescriptorSeek(MemListDescriptorRef seekDescriptor, MemListWhence whence, SInt32 offset, SInt32 *newOffset);

extern OSStatus MemListGetExtent(MemListDescriptorRef descriptor, ByteCount requestedSize, LogicalAddress *staticLogicalAddress, PhysicalAddress *physicalAddress, ByteCount *extentLen);

extern OSStatus MemListGetPage(MemListDescriptorRef descriptor, LogicalAddress *staticLogicalAddress, PhysicalAddress *physicalAddress, ByteCount *bytesUsedInPage);

/*
******************************************************************************
 *******************************************************************************

	Memory List Descriptor Usage
	
 *******************************************************************************
 *****************************************************************************
*/
extern OSStatus MemListDescriptorDataCopy(MemListDescriptorRef srcDescriptor, MemListDescriptorRef destDescriptor, ByteCount bytesToCopy);

extern OSStatus MemListDescriptorDataCopyToMemory(MemListDescriptorRef srcDescriptor, LogicalAddress destBuffer, ByteCount bytesToCopy);

extern OSStatus MemListDescriptorDataCopyFromMemory(LogicalAddress srcBuffer, MemListDescriptorRef destDescriptor, ByteCount bytesToCopy);

extern OSStatus MemListDescriptorDataCompare(MemListDescriptorRef descriptor1, MemListDescriptorRef descriptor2, ByteCount bytesToCompare, Boolean *different, ByteCount *firstDifferentByte);

extern OSStatus MemListDescriptorDataCompareWithMemory(MemListDescriptorRef descriptor, LogicalAddress buffer, ByteCount bytesToCompare, Boolean *different, ByteCount *firstDifferentByte);

/*
******************************************************************************
 *******************************************************************************

	Memory List Extended Functionality
	
 *******************************************************************************
 *****************************************************************************
*/
extern OSStatus MemListDelete(MemListRef deleteList);

extern OSStatus MemListExportIOPreparationTable(MemListDescriptorRef srcDescriptor, IOPreparationTable **outputTable);

extern OSStatus MemListDeleteIOPreparationTable(MemListDescriptorRef srcDescriptor, IOPreparationTable *deleteTable);


#pragma options align=reset
#endif /* PRAGMA_ALIGN_SUPPORTED */

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __IOMEMORYLISTS__ */

